@@ -283,29 +283,45 @@ class Camera(BaseCamera):
 
 
 # camera device
-class BaseState(TypedDict):
-    timestamp: int
-    lastTriggered: int
-
-
-class Detection(TypedDict):
+class BaseDetection(TypedDict):
     id: NotRequired[str]
+
+
+class MotionDetection(BaseDetection):
     label: NotRequired[str]
     boundingBox: Tuple[int, int, int, int]
 
 
+class ObjectDetection(BaseDetection):
+    label: NotRequired[str]
+    boundingBox: Tuple[int, int, int, int]
+
+
+class BaseState(TypedDict):
+    timestamp: int
+    lastEvent: Union[
+        "LightState",
+        "MotionState",
+        "AudioState",
+        "ObjectState",
+        "DoorbellState",
+        "SirenState",
+        "BatteryState",
+    ]
+
+
 class MotionSetEvent(TypedDict):
     state: bool
-    detections: List[Detection]
+    detections: List[MotionDetection]
 
 
 class AudioSetEvent(TypedDict):
     state: bool
+    db: NotRequired[Optional[int]]
 
 
 class ObjectSetEvent(TypedDict):
-    state: bool
-    detections: List[Detection]
+    detections: List[ObjectDetection]
 
 
 class LightSetEvent(TypedDict):
@@ -318,42 +334,34 @@ class DoorbellSetEvent(TypedDict):
 
 class SirenSetEvent(TypedDict):
     state: bool
+    level: NotRequired[Optional[int]]
 
 
 class BatterySetEvent(TypedDict):
-    state: int
+    level: int
+    charging: NotRequired[Optional[bool]]
+    lowBattery: NotRequired[Optional[bool]]
 
 
-class DeviceSetEvent(TypedDict):
-    pass
+class LightState(BaseState, LightSetEvent): ...
 
 
-class LightState(BaseState, LightSetEvent):
-    pass
+class MotionState(BaseState, MotionSetEvent): ...
 
 
-class MotionState(BaseState, MotionSetEvent):
-    pass
+class AudioState(BaseState, AudioSetEvent): ...
 
 
-class AudioState(BaseState, AudioSetEvent):
-    pass
+class DoorbellState(BaseState, DoorbellSetEvent): ...
 
 
-class DoorbellState(BaseState, DoorbellSetEvent):
-    pass
+class SirenState(BaseState, SirenSetEvent): ...
 
 
-class SirenState(BaseState, SirenSetEvent):
-    pass
+class ObjectState(BaseState, ObjectSetEvent): ...
 
 
-class ObjectState(BaseState, ObjectSetEvent):
-    pass
-
-
-class BatteryState(BaseState, BatterySetEvent):
-    pass
+class BatteryState(BaseState, BatterySetEvent): ...
 
 
 State = Union[
@@ -455,7 +463,7 @@ class CameraPrebufferDelegate(ABC):
 
 class CameraSource(Protocol):
     # CameraInput
-    _id: str
+    id: str
     name: str
     roles: List["CameraRoles"]
     urls: StreamUrls
@@ -564,11 +572,7 @@ class CameraDevice(Protocol):
     async def generate_frames(self) -> AsyncGenerator[VideoFrame, None]: ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_ice_servers(self) -> List[IceServer]: ...
-    # async def create_session(self, options: Any) -> Any: ... # todo
-    # async def stream_video(self, source_name: str, options: Any) -> None: ...  # todo
-    # async def record_to_file(
-    #     self, source_name: str, output_path: str, duration: Optional[int] = 60  # todo
-    # ) -> None: ...
+
     async def get_value(
         self, state_name: str
     ) -> Union[
